import React from 'react';
import ReactDOM from 'react-dom';
import { arc } from 'd3';

const width = 960;
const height = 500;
const centerX = width / 2;
const centerY = height / 2;
const strokeWidth = 20;
const eyeOffsetX = 90;
const eyeOffsetY = 100;
const eyeRadiusX = 50;
const eyeRadiusY = eyeRadiusX * 0.6;
const irisRadius = eyeRadiusX * 0.4;
const eyeStrokeWidth = 5;
const mouthWidth = 20;
const mouthRadius = 140;

const mouthArc = arc()
	.innerRadius(mouthRadius)
	.outerRadius(mouthRadius + mouthWidth)
	.startAngle(Math.PI / 2)
	.endAngle(Math.PI * 3/2);

const Eye = ({offsetX, offsetY, radiusX}) => (
  <g>
    <ellipse
      cx={offsetX}
      cy={offsetY}
      ry={radiusX * 0.6}
      rx={radiusX}
      fill="white"
      stroke="black"
      stroke-width={eyeStrokeWidth}
    />
    <circle
      cx={offsetX}
      cy={offsetY}
      r={radiusX * 0.4}
    />
  </g>
)

const App = () => (
    <svg width={width} height={height}>
    	<g transform={`translate(${centerX}, ${centerY})`}>
        <circle
          r={centerY - strokeWidth / 2}
          fill="yellow"
          stroke="black"
          stroke-width={strokeWidth}
        />
        <Eye
          offsetX={-eyeOffsetX}
          offsetY={-eyeOffsetY}
          radiusX={eyeRadiusX}
        />
        <Eye
          offsetX={eyeOffsetX}
          offsetY={-eyeOffsetY}
          radiusX={eyeRadiusX}
        />
        <Eye
          offsetX={0}
          offsetY={-150}
          radiusX={eyeRadiusX}
        />
        <path d={mouthArc()}/>
    	</g>
    </svg>
);

const rootElement = document.getElementById("root");
ReactDOM.render(<App />, rootElement);